"""
`contextily`: create context with map tiles in Python
"""

import xyzservices.providers as providers
from .place import Place, plot_map
from .tile import *
from .plotting import add_basemap, add_attribution

__version__ = "1.2.0"
